==> zio-aws-securityhub_2.13-5.17.115.1-sources.jar: zio/aws/securityhub/model/AwsSnsTopicDetails.scala <==
package zio.aws.securityhub.model
import zio.ZIO
import zio.aws.securityhub.model.primitives.NonEmptyString
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class AwsSnsTopicDetails(
    kmsMasterKeyId: Option[NonEmptyString] = None,
    subscription: Option[
      Iterable[zio.aws.securityhub.model.AwsSnsTopicSubscription]
    ] = None,
    topicName: Option[NonEmptyString] = None,
    owner: Option[NonEmptyString] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.securityhub.model.AwsSnsTopicDetails = {
    import AwsSnsTopicDetails.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.securityhub.model.AwsSnsTopicDetails
      .builder()
      .optionallyWith(
        kmsMasterKeyId.map(value =>
          NonEmptyString.unwrap(value): java.lang.String
        )
      )(_.kmsMasterKeyId)
      .optionallyWith(
        subscription.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.subscription)
      .optionallyWith(
        topicName.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.topicName)
      .optionallyWith(
        owner.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.owner)
      .build()
  }
  def asReadOnly: zio.aws.securityhub.model.AwsSnsTopicDetails.ReadOnly =
    zio.aws.securityhub.model.AwsSnsTopicDetails.wrap(buildAwsValue())
}
object AwsSnsTopicDetails {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.securityhub.model.AwsSnsTopicDetails
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.securityhub.model.AwsSnsTopicDetails =
      zio.aws.securityhub.model.AwsSnsTopicDetails(
        kmsMasterKeyId.map(value => value),
        subscription.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        topicName.map(value => value),
        owner.map(value => value)
      )
    def kmsMasterKeyId: Option[NonEmptyString]
    def subscription: Option[
      List[zio.aws.securityhub.model.AwsSnsTopicSubscription.ReadOnly]
    ]
    def topicName: Option[NonEmptyString]
    def owner: Option[NonEmptyString]
    def getKmsMasterKeyId: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("kmsMasterKeyId", kmsMasterKeyId)
    def getSubscription: ZIO[Any, AwsError, List[
      zio.aws.securityhub.model.AwsSnsTopicSubscription.ReadOnly
    ]] = AwsError.unwrapOptionField("subscription", subscription)
    def getTopicName: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("topicName", topicName)
    def getOwner: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("owner", owner)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.securityhub.model.AwsSnsTopicDetails
  ) extends zio.aws.securityhub.model.AwsSnsTopicDetails.ReadOnly {
    override val kmsMasterKeyId: Option[NonEmptyString] = scala
      .Option(impl.kmsMasterKeyId())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val subscription: Option[
      List[zio.aws.securityhub.model.AwsSnsTopicSubscription.ReadOnly]
    ] = scala
      .Option(impl.subscription())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.securityhub.model.AwsSnsTopicSubscription.wrap(item)
        }.toList
      )
    override val topicName: Option[NonEmptyString] = scala
      .Option(impl.topicName())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val owner: Option[NonEmptyString] = scala
      .Option(impl.owner())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.securityhub.model.AwsSnsTopicDetails
  ): zio.aws.securityhub.model.AwsSnsTopicDetails.ReadOnly = new Wrapper(impl)
}

==> zio-aws-securityhub_2.13-5.17.205.1-sources.jar: zio/aws/securityhub/model/AwsSnsTopicDetails.scala <==
package zio.aws.securityhub.model
import zio.ZIO
import zio.aws.securityhub.model.primitives.NonEmptyString
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class AwsSnsTopicDetails(
    kmsMasterKeyId: Optional[NonEmptyString] = Optional.Absent,
    subscription: Optional[
      Iterable[zio.aws.securityhub.model.AwsSnsTopicSubscription]
    ] = Optional.Absent,
    topicName: Optional[NonEmptyString] = Optional.Absent,
    owner: Optional[NonEmptyString] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.securityhub.model.AwsSnsTopicDetails = {
    import AwsSnsTopicDetails.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.securityhub.model.AwsSnsTopicDetails
      .builder()
      .optionallyWith(
        kmsMasterKeyId.map(value =>
          NonEmptyString.unwrap(value): java.lang.String
        )
      )(_.kmsMasterKeyId)
      .optionallyWith(
        subscription.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.subscription)
      .optionallyWith(
        topicName.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.topicName)
      .optionallyWith(
        owner.map(value => NonEmptyString.unwrap(value): java.lang.String)
      )(_.owner)
      .build()
  }
  def asReadOnly: zio.aws.securityhub.model.AwsSnsTopicDetails.ReadOnly =
    zio.aws.securityhub.model.AwsSnsTopicDetails.wrap(buildAwsValue())
}
object AwsSnsTopicDetails {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.securityhub.model.AwsSnsTopicDetails
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.securityhub.model.AwsSnsTopicDetails =
      zio.aws.securityhub.model.AwsSnsTopicDetails(
        kmsMasterKeyId.map(value => value),
        subscription.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        topicName.map(value => value),
        owner.map(value => value)
      )
    def kmsMasterKeyId: Optional[NonEmptyString]
    def subscription: Optional[
      List[zio.aws.securityhub.model.AwsSnsTopicSubscription.ReadOnly]
    ]
    def topicName: Optional[NonEmptyString]
    def owner: Optional[NonEmptyString]
    def getKmsMasterKeyId: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("kmsMasterKeyId", kmsMasterKeyId)
    def getSubscription: ZIO[Any, AwsError, List[
      zio.aws.securityhub.model.AwsSnsTopicSubscription.ReadOnly
    ]] = AwsError.unwrapOptionField("subscription", subscription)
    def getTopicName: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("topicName", topicName)
    def getOwner: ZIO[Any, AwsError, NonEmptyString] =
      AwsError.unwrapOptionField("owner", owner)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.securityhub.model.AwsSnsTopicDetails
  ) extends zio.aws.securityhub.model.AwsSnsTopicDetails.ReadOnly {
    override val kmsMasterKeyId: Optional[NonEmptyString] =
      zio.aws.core.internal
        .optionalFromNullable(impl.kmsMasterKeyId())
        .map(value =>
          zio.aws.securityhub.model.primitives.NonEmptyString(value)
        )
    override val subscription: Optional[
      List[zio.aws.securityhub.model.AwsSnsTopicSubscription.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.subscription())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.securityhub.model.AwsSnsTopicSubscription.wrap(item)
        }.toList
      )
    override val topicName: Optional[NonEmptyString] = zio.aws.core.internal
      .optionalFromNullable(impl.topicName())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
    override val owner: Optional[NonEmptyString] = zio.aws.core.internal
      .optionalFromNullable(impl.owner())
      .map(value => zio.aws.securityhub.model.primitives.NonEmptyString(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.securityhub.model.AwsSnsTopicDetails
  ): zio.aws.securityhub.model.AwsSnsTopicDetails.ReadOnly = new Wrapper(impl)
}
